@@ -8,10 +8,9 @@ else:
     import urllib2
     from urllib import urlencode
 
-from .filesplit import Filesplit
 from datetime import datetime
 
-__version__ = '0.4.0'
+__version__ = '0.5.0'
 URL = 'https://d3design.tools'
 
 
@@ -21,39 +20,17 @@ class Client(object):
         Args:
             user (str): Username.
             apiToken (str): API token.
-            memory (int, optional): Amount of memory to allocated for the Client in GB. Defaults to 2 GB.
     """
-    def __init__(self,user,apiToken,memory=2.0):
+    def __init__(self,user,apiToken):
         self._user = user
         self._apiToken = apiToken
-        self.memory = memory
         # Check credentials and initialize user.
         response = self.__post(URL+'/cloud_api_initialize',{'version':__version__})
         if response['valid']:
             print('INFO [client]: Connected to D3 Cloud.')
         if not response['valid']:
             print(response['info'])
-            return
-
-    # Properties.
-
-    @property
-    def memory(self):
-        """Amount of memory allocated for the Client in GB.
-
-        Returns:
-            float: Amount of memory allocated for the Client in GB.
-        """
-        return self._memory
-    
-    @memory.setter
-    def memory(self,memory):
-        """Set amount of memory allocated for the Client in GB.
-
-        Args:
-            memory (float): Amount of memory allocated for the Client in GB.
-        """
-        self._memory = max(memory,0.5)
+            sys.exit()
 
     # Private.
 
@@ -205,48 +182,32 @@ class Client(object):
         if os.path.splitext(simulationGeometries)[1] != '.zip':
             print('WARNING [client|newSimulation]: Please zip geometries.')
             return False
-        fs = Filesplit()
-        temporaryDir = '.tmp_split_'+datetime.now().strftime("%m%d%Y%H%M%S")
-        if os.path.exists(temporaryDir): # Required in case user runs this script multiple times very quickly.
-            shutil.rmtree(temporaryDir)
-        os.mkdir(temporaryDir)
-        size = os.path.getsize(simulationGeometries)/1024.0**3
-        nChunks = int(size / self.memory*0.8 + 1)
-        def callback(subfile,size):
-            print("DEBUG [client|newSimulation]: Splitting into subfile "+str(subfile).split('_')[-1].replace('.zip','')+" of "+str(nChunks))
-        fs.split(file=simulationGeometries,callback=callback,split_size=self.memory*0.8*(1024**3),output_dir=temporaryDir,newline=True,include_header=True)
-        subfilesToUpload = [os.path.join(temporaryDir,f) for f in os.listdir(temporaryDir)]
-        for i,subfile in enumerate(subfilesToUpload):
-            print('DEBUG [client|newSimulation]: Uploading part '+str(i+1)+' of '+str(len(subfilesToUpload))+'...')
-            with open(subfile, 'rb') as f:
-                r = requests.post(
-                    URL+'/upload',
-                    files = {'file1': f},
-                    data = {
-                        'simulationType':simulationType,
-                        'api':'true',
-                        'username':self._user,
-                        'apiToken':self._apiToken,
-                        'projectName':projectName,
-                        'caseName':simulationName,
-                        'lastPart':'true' if i+1 == len(subfilesToUpload) else 'false'
-                    },
-                    verify=False # ! TODO Quick unsafe hack until certs are served.
-                )
-                if r.status_code == 200:
-                    response = r.json()
-                    if response['valid']:
-                        print('INFO [client|newSimulation]: Geometries uploaded successfully.')
-                    else:
-                        print('ERROR [client|newSimulation]: Something went wrong uploading geometries:')
-                        print(response['info'])
-                        shutil.rmtree(temporaryDir)
-                        return False
+
+        with open(simulationGeometries, 'rb') as f:
+            r = requests.post(
+                URL+'/upload',
+                files = {'file1': f},
+                data = {
+                    'simulationType':simulationType,
+                    'api':'true',
+                    'username':self._user,
+                    'apiToken':self._apiToken,
+                    'projectName':projectName,
+                    'caseName':simulationName
+                },
+                verify=False # ! TODO Quick unsafe hack until certs are served.
+            )
+            if r.status_code == 200:
+                response = r.json()
+                if response['valid']:
+                    print('INFO [client|newSimulation]: Geometries uploaded successfully.')
                 else:
-                    print('ERROR [client|newSimulation]: Server error '+str(r.status_code)+' during geometry upload. Please try again and if the problem persists contact support.')
-                    shutil.rmtree(temporaryDir)
+                    print('ERROR [client|newSimulation]: Something went wrong uploading geometries:')
+                    print(response['info'])
                     return False
-        shutil.rmtree(temporaryDir)
+            else:
+                print('ERROR [client|newSimulation]: Server error '+str(r.status_code)+' during geometry upload. Please try again and if the problem persists contact support.')
+                return False
 
         # Wait until (non-blocking) geometry upload finishes.
         status = 'processing'
